/*
** Module   : EditorWidget.java
** Abstract : server side Editor widget implementation
**
** Copyright (c) 2006-2013, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**           Golden Code Development Corporation
**                      CONFIDENTIAL
**
** -#- -I- --Date-- --JPRM-- ----------------Description-----------------
** 001 SIY 20060427   @26084 Server side part of the EDITOR widget.
** 002 GES 20060803   @28373 Cleanup and refactoring.
** 003 GES 20080320   @37585 Added TYPE attribute.
** 004 SIY 20111101          Updated imports.
** 005 CA  20130129          Added setLarge stub, for EDITOR LARGE.
*/

package com.goldencode.p2j.ui;

import com.goldencode.p2j.util.*;

/**
 * Server side implementation of the EDITOR widget.
 */
public class EditorWidget
extends ControlTextWidget
{
   /** Reference to our configuration which is pre-cast to the proper type. */
   private EditorConfig ec = null;
   
   /**
    * Default constructor.
    */
   public EditorWidget()
   {
      super(new EditorConfig(ComponentConfig.EDITOR, null));
      ec = (EditorConfig) config;
   }

   public void setLarge(boolean _large)
   {
      // TODO:
   }
   
   /**
    * Set value of the INNER-LINES attribute.
    * 
    * @param   lines 
    *          The new value for the attribute.
    */
   public void setInnerLines(int lines)
   {
      ec.setInnerLines(lines);
      frame.pushScreenDefinition();
   }
   
   /**
    * Set value of the INNER-LINES attribute.
    * 
    * @param   lines 
    *          The new value for the attribute.
    */
   public void setInnerLines(NumberType lines)
   {
      if (lines.isUnknown())
         return;
      
      setInnerLines(lines.intValue());
   }
   
   /**
    * Set value of the INNER-CHARS attribute.
    * 
    * @param   chars 
    *          The new value for the attribute.
    */
   public void setInnerChars(int chars)
   {
      ec.setInnerChars(chars);
      frame.pushScreenDefinition();
   }
   
   /**
    * Set value of the INNER-CHARS attribute.
    * 
    * @param   chars 
    *          The new value for the attribute.
    */
   public void setInnerChars(NumberType chars)
   {
      if (chars.isUnknown())
         return;
      
      setInnerChars(chars.intValue());
   }

   /**
    * Set value of the MAX-CHARS attribute.
    * 
    * @param   chars 
    *          The new value for the attribute.
    */
   public void setMaxChars(int chars)
   {
      ec.setMaxChars(chars);
      frame.pushScreenDefinition();
   }

   /**
    * Set value of the MAX-CHARS attribute.
    * 
    * @param   chars 
    *          The new value for the attribute.
    */
   public void setMaxChars(NumberType chars)
   {
      if (chars.isUnknown())
         return;
      
      setMaxChars(chars.intValue());
   }
   
   /**
    * Set value of the BUFFER-CHARS attribute.
    * 
    * @param   chars 
    *          The new value for the attribute.
    */
   public void setBufferChars(int chars)
   {
      ec.setBufferChars(chars);
      frame.pushScreenDefinition();
   }
   
   /**
    * Set value of the BUFFER-CHARS attribute.
    * 
    * @param   chars 
    *          The new value for the attribute.
    */
   public void setBufferChars(NumberType chars)
   {
      if (chars.isUnknown())
         return;
      
      setBufferChars(chars.intValue());
   }
   
   /**
    * Set value of the BUFFER-LINES attribute.
    * 
    * @param   lines
    *          The new value for the attribute.
    */
   public void setBufferLines(int lines)
   {
      ec.setBufferLines(lines);
      frame.pushScreenDefinition();
   }
   
   /**
    * Set value of the BUFFER-LINES attribute.
    * 
    * @param   lines
    *          The new value for the attribute.
    */
   public void setBufferLines(NumberType lines)
   {
      if (lines.isUnknown())
         return;
      
      setBufferLines(lines.intValue());
   }
   
   /**
    * Set value of the BOX attribute as opposite to passed value.
    * 
    * @param   box
    *          The new value for the attribute.
    */
   public void setNoBox(boolean box)
   {
      ec.setBox(!box);
      frame.pushScreenDefinition();
   }

   /**
    * Set value of the BOX attribute as opposite to passed value.
    * 
    * @param   box
    *          The new value for the attribute.
    */
   public void setNoBox(logical box)
   {
      if (box.isUnknown())
         return;
      
      setNoBox(box.booleanValue());
   }
   
   /**
    * Set value of the WORD-WRAP attribute as opposite to passed value.
    * 
    * @param   wordwrap
    *          The new value for the attribute.
    */
   public void setNoWordWrap(boolean wordwrap)
   {
      ec.setWordWrap(!wordwrap);
      frame.pushScreenDefinition();
   }

   /**
    * Set value of the WORD-WRAP attribute as opposite to passed value.
    * 
    * @param   wordwrap
    *          The new value for the attribute.
    */
   public void setNoWordWrap(logical wordwrap)
   {
      if (wordwrap.isUnknown())
         return;
      
      setNoWordWrap(wordwrap.booleanValue());
   }
   
   /**
    * Set value of the SCROLLBAR-VERTICAL attribute.
    * 
    * @param   vertical
    *          The new value for the attribute.
    */
   public void setScrollbarVertical(boolean vertical)
   {
      ec.setScrollbarVertical(vertical);
      frame.pushScreenDefinition();
   }

   /**
    * Set value of the SCROLLBAR-VERTICAL attribute.
    * 
    * @param   vertical
    *          The new value for the attribute.
    */
   public void setScrollbarVertical(logical vertical)
   {
      if (vertical.isUnknown())
         return;
      
      setScrollbarVertical(vertical.booleanValue());
   }
   
   /**
    * Set value of the SCROLLBAR-HORIZONTAL attribute.
    * 
    * @param   horizontal
    *          The new value for the attribute.
    */
   public void setScrollbarHorizontal(boolean horizontal)
   {
      ec.setScrollbarHorizontal(horizontal);
      frame.pushScreenDefinition();
   }

   /**
    * Set value of the SCROLLBAR-HORIZONTAL attribute.
    * 
    * @param   horizontal
    *          The new value for the attribute.
    */
   public void setScrollbarHorizontal(logical horizontal)
   {
      if (horizontal.isUnknown())
         return;
      
      setScrollbarHorizontal(horizontal.booleanValue());
   }
   
   /**
    * Obtains the type of widget description.
    *
    * @return   Always "EDITOR".
    */
   public character getType()
   {
      return new character("EDITOR");
   }
}
