/*
** Module   : TextImpl.java
** Abstract :
**
** Copyright (c) 2011-2013, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**           Golden Code Development Corporation
**                      CONFIDENTIAL
**
** -#- -I- --Date-- -----------------------Description------------------------
** 001 SIY 20111202 Extracted from Text.
** 002 CA  20130129 Import change.
**
*/

package com.goldencode.p2j.ui.chui;

import com.goldencode.p2j.ui.*;
import com.goldencode.p2j.ui.client.*;
import com.goldencode.p2j.ui.client.Text;
import com.goldencode.p2j.ui.client.format.*;
import com.goldencode.p2j.util.*;
import com.goldencode.util.*;

/**
 * CHUI-specific {@link Text} implementation.
 */
@SuppressWarnings("unchecked")
public class TextImpl
extends Text
{
   /**
    * Special constructor used to restore component using given configuration.
    * 
    * @param   cfg
    *          Configuration data.
    */
   public TextImpl(ComponentConfig cfg)
   {
      super(cfg);
   }

   /**
    * Actual drawing routine.
    *
    * @param   color
    *          Color for drawing.
    */
   @Override
   public void draw(Color color)
   {
      if (assigned && config().getState() == ScreenBuffer.UNINITIALIZED)
         config().setState(ScreenBuffer.UNCHANGED);
      
      Color dc = UiUtils.getDcolor(this);

      selected = !Utils.equals(color, dc);

      String display = getText(true);
      
      // obtain the initialization status
      boolean uninit = (config.getState() == ScreenBuffer.UNINITIALIZED);
      
      // If uninitialized and not for input and not date fill-in (in this case
      // separators should be displayed), display blanks instead.
      // TODO: probably it should be replaced by variable initialization
      //       in FrameHelper.clearComponents().
      if (uninit &&
          !(appFormat != null &&
            appFormat instanceof DateFormat &&
            isEnabled()))
      {
         int width = display.length();
         display = StringHelper.repeatChar(' ', width);
      }
      
      Point p = new Point(screenLocation());
      
      if (p.x == -1 || p.y == -1)
         return;

      OutputManager screen = screen();
      
      screen.at(p).append(display, color);

      if (height() > 1)
      {
         String spaces = DisplayFormat.generateSpaces(width());
         
         for (int i = 1; i < height(); ++i)
         {
            p.y++;
            screen.at(p);
            
            if (config.isHeader() && drawLine && i == (height() - 1))
               screen.hLine(width(), color);
            else
               screen.append(spaces, Color.DEFAULT);
         }
      }

      //if (widgetFocused)
      if (hasFocus() && isEnabled())
         drawCaret();
   }
}
